@@ -465,7 +465,7 @@ class DescribeEventsRequest(AbstractModel):
         :type NextToken: int
         :param MaxResults: 返回日志的最大条数（最大 50 条）
         :type MaxResults: int
-        :param LookupAttributes: 检索条件（目前支持 RequestId：请求 ID、EventName：事件名称、ActionType：操作类型（Write：写；Read：读）、PrincipalId：子账号、ResourceType：资源类型、ResourceName：资源名称、AccessKeyId：密钥 ID、SensitiveAction：是否敏感操作、ApiErrorCode：API 错误码、CamErrorCode：CAM 错误码）
+        :param LookupAttributes: 检索条件（目前支持 RequestId：请求 ID、EventName：事件名称、ActionType：操作类型（Write：写；Read：读）、PrincipalId：子账号、ResourceType：资源类型、ResourceName：资源名称、AccessKeyId：密钥 ID、SensitiveAction：是否敏感操作、ApiErrorCode：API 错误码、CamErrorCode：CAM 错误码、Tags：标签（AttributeValue格式：[{"key":"*","value":"*"}]））
         :type LookupAttributes: list of LookupAttribute
         :param IsReturnLocation: 是否返回 IP 归属地（1 返回，0 不返回）
         :type IsReturnLocation: int
